version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1200

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

// community data
cd $dataraw
cd 2011
use community, clear
duplicates tag communityID, gen(reps)
keep if reps == 0 
tempfile community
save   "`community'", replace

cd $dataready
use charls_females.dta, clear

// generate delta children outcomes
gen     lchildren = l.children
drop if lchildren ==.
gen dchildren = children - l.children

// merge community-level data
merge m:1 communityID using "`community'", keepusing(jh*)
keep if _merge != 2

// data groups
egen ageyeargroups1 = group(age year province_code)
egen ageyeargroups2 = group(age year communityID)
egen segroup       = group(province_code birthyear)

// construct fine/permit variables
// construct fine/permit variables
gen    allowedaddchild2000 = allowedaddchild if year == 1999
bysort simpleID : egen allowedaddchild2005 = mean(allowedaddchild2000)
replace allowedaddchild = allowedaddchild2005 if year >= 2000 & allowedaddchild2005 !=.
replace fine = 0 if allowedaddchild == 0

xtset simpleID age
# delimit
reghdfe dchildren  l.fine
		  if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
		  absorb(i.simpleID i.ageyeargroups1) cluster(segroup);
# delimit cr
keep if e(sample) == 1

// policy start
// measure (1) - community based 
bysort       simpleID : egen firstobserved = min(year)
bysort    communityID : egen policystart_1 = min(jh019)
replace policystart_1 = firstobserved if firstobserved > policystart_1 

// measure (2) - my documentation based 
sort simpleID age
gen     deltafine       = abs(fine - l.fine)
gen     policystart_2b   = year if deltafine > 0 & deltafine !=.  
replace policystart_2b   = year if fine      > 0 & fine !=. 
bysort       simpleID : egen policystart_2 = min(policystart_2b)

gen     finealt = 0         if jh026 == 2
replace finealt = 0         if jh026 == 1 & year <  jh026_1 
replace finealt = jh027     if jh026 == 1 & year >= jh026_1 & year !=.

replace finealt = jh029b_1_ if jh028 == 1 & year >= jh029a_1_ & year !=.
replace finealt = jh029b_2_ if jh028 == 1 & year >= jh029a_2_ & year !=.
replace finealt = jh029b_3_ if jh028 == 1 & year >= jh029a_3_ & year !=.

// with exemptions set by local leaders
gen     finealt_exp = finealt
replace finealt_exp = 0 if  jh020 == 2               &  firstchildgirl == 1 & selforspousehan == 1
replace finealt_exp = 0 if (jh020 == 3 | jh020 == 4) & selforspousehan == 1

// return to original fine in change in year of change and after  
replace finealt_exp = finealt if jh021 == 1 & year >= jh023 & year !=.

// put in exemptions
replace finealt_exp = 0 if  jh021 == 1 &  jh022 == 2               &  firstchildgirl == 1 & selforspousehan == 1 & year >= jh023 & year !=.
replace finealt_exp = 0 if  jh021 == 1 & (jh022 == 3 | jh022 == 4) & selforspousehan == 1 & year >= jh023 & year !=.

// live off from only one observation for minorities
replace finealt_exp = 0 if  jh025 == 2               &  firstchildgirl == 1 & selforspousehan == 0
replace finealt_exp = 0 if (jh025 == 3 | jh025 == 4) & selforspousehan == 0

summ    finealt_exp, d
replace finealt_exp =.  if finealt_exp > r(p95)
replace finealt_exp = 0 if allowedaddchild == 0

replace fine =.        if finealt_exp ==. | children ==.
replace finealt_exp =. if fine ==.        | children ==.

foreach var of varlist fine finealt_exp {
	summ    `var' if year == 1979
	replace `var' = `var'/r(mean)
	replace `var' = log(`var' + 1)
}
cd $output
drop _merge
save fine_event_percentiles.dta, replace

// run bootstrap first to then proceed with plot
foreach b of numlist 1(1)$bootstraps {
	use fine_event_percentiles.dta, clear
	drop segroup
	egen segroup       = group(province_code birthyear)
	keep simpleID segroup
	duplicates drop simpleID, force
	bsample, strata(segroup)
	drop segroup
	gen simpleIDalt = _n
	expand 166
	bysort simpleIDalt : egen age = seq()
	replace age = age - 63
	merge m:m simpleID age using fine_event_percentiles.dta
	keep if _merge == 3
	drop simpleID _merge
	rename simpleIDalt simpleID
	xtset simpleID age
	
	// main estimation
	# delimit
	reghdfe  fine        if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
			 absorb(i.simpleID i.ageyeargroups2) resid(fine_resid1) vce(cluster segroup);
	# delimit cr
	replace fine_resid1 =. if e(sample) == 0

	# delimit
	reghdfe  finealt_exp if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
			 absorb(i.simpleID i.ageyeargroups2) resid(fine_resid2) vce(cluster segroup);
	# delimit cr
	replace fine_resid2 =. if e(sample) == 0

	foreach num of numlist 1 2 {
		# delimit
		reghdfe  children if year >= 1979 & year <= 2000 & age >= 15 & age <= 45, 
				 absorb(i.simpleID i.ageyeargroups`num') resid(children_resid`num') vce(cluster segroup);
		# delimit cr
		replace children_resid`num' =. if e(sample) == 0
		summ    children_resid`num' 
		replace children_resid`num' = (children_resid`num' - r(mean)) / r(sd)
	}

	// percentiles of interest
	local num = 0 
	foreach var of varlist fine_resid1 {
		local num = `num' + 1
		foreach p of numlist 60(5)95 {
			summ fine_resid`num', d
			bysort year: egen maxfine_t`num' = pctile(fine_resid`num'), p(`p')
			
			
			gen     maxcountaux_t`num' = 0 if fine_resid`num' !=.               & maxfine_t`num' !=. 
			replace maxcountaux_t`num' = 1 if fine_resid`num'  > maxfine_t`num' & fine_resid`num'     !=.               
			
			xtset simpleID age
			bysort simpleID : gen maxcount_t`num' = sum(maxcountaux_t`num') if maxcountaux_t`num' !=.
			

			gen     class_t`num' = 0 if fine_resid`num' !=.        & children !=.      & maxcount_t`num' !=.
			replace class_t`num' = 1 if maxcount_t`num' >= 2  & fine_resid`num' !=.    & children !=.        & maxcount_t`num' !=.
			
			// define event
			gen dclass_t`num' = class_t`num' - l.class_t`num'
			gen yeareventaux_t`num' = year if dclass_t`num' == 1
			bysort simpleID : egen yearevent_t`num' = min(yeareventaux_t`num') if class_t`num' !=.
			gen eventtime_t`num'_p`p' = year - yearevent_t`num'
			drop maxfine_t`num' maxcountaux_t`num' maxcount_t`num' class_t`num' dclass_t`num' yeareventaux_t`num' yearevent_t`num'
		}
	}

	foreach var of varlist fine_resid2 {
		local num = `num' + 1
		foreach p of numlist 60(5)95 {
			summ fine_resid`num', d
			bysort year: egen maxfine_t`num' = pctile(fine_resid`num'), p(`p')
			
			
			gen     maxcountaux_t`num' = 0 if fine_resid`num' !=.               & maxfine_t`num' !=. 
			replace maxcountaux_t`num' = 1 if fine_resid`num'  > maxfine_t`num' & fine_resid`num'     !=.               
			
			xtset simpleID age
			bysort simpleID : gen maxcount_t`num' = sum(maxcountaux_t`num') if maxcountaux_t`num' !=.
			

			gen     class_t`num' = 0 if fine_resid`num' !=.        & children !=.      & maxcount_t`num' !=.
			replace class_t`num' = 1 if maxcount_t`num' >= 2  & fine_resid`num' !=.    & children !=.        & maxcount_t`num' !=.
			
			// define event
			gen dclass_t`num' = class_t`num' - l.class_t`num'
			gen yeareventaux_t`num' = year if dclass_t`num' == 1
			bysort simpleID : egen yearevent_t`num' = min(yeareventaux_t`num') if class_t`num' !=.
			gen eventtime_t`num'_p`p' = year - yearevent_t`num'
			drop maxfine_t`num' maxcountaux_t`num' maxcount_t`num' class_t`num' dclass_t`num' yeareventaux_t`num' yearevent_t`num'
		}
	}

	// events
	foreach num of numlist 1 2 {
		foreach p of numlist 60(5)95 {
			local numel = 0
			foreach numy of numlist -6(1)4 {
				local numel = `numel' + 1
				gen eventtime_t`num'_`numel'_p`p' = eventtime_t`num'_p`p' == `numy'
			}
			reg children_resid`num' eventtime_t`num'_1_p`p'-eventtime_t`num'_11_p`p' if eventtime_t`num'_p`p' >= -6 & eventtime_t`num'_p`p' <= 4, nocons
			matrix acr3_t`num'_p`p' = e(b)
			matrix acr3_t`num'_p`p' = acr3_t`num'_p`p'[1,1..11]'
		}
	}

	matrix acrall = J(11,1,.)
	foreach p of numlist 60(5)95 {
		matrix acrall_p`p' = [acr3_t1_p`p',acr3_t2_p`p']
		matrix colnames acrall_p`p' = acr3_t1_p`p' acr3_t2_p`p'
		matrix acrall          = [acrall,acrall_p`p']
	}
	matrix acrall = acrall[1...,2...]

	clear
	svmat   acrall, names(col)
	gen     eventtime = _n - 6

	foreach var of varlist acr* {
		summ    `var' if eventtime == -1
		replace `var' = `var' - r(mean)
	}

	// average before and after 
	drop if eventtime == -1
	replace eventtime =  1 if eventtime >= 0
	replace eventtime =  0 if eventtime < 0

	collapse acr*, by(eventtime)
	aorder
	order eventtime 
	mkmat acr3_t1*, matrix(acr_t1)
	mkmat acr3_t2*, matrix(acr_t2)

	clear
	foreach num of numlist 1 2 {
		matrix acr_t`num' = acr_t`num''
		svmat  acr_t`num'
		rename acr_t`num'1 acr_t`num'0
		rename acr_t`num'2 acr_t`num'1
	} 
	gen n1 = _n*5 + 55
	gen n2 = _n*5 + 60
	
	foreach num of numlist 1 2 {
		foreach p of numlist 0 1 { 
			summ   acr_t`num'`p'  if n`num' > 60 & n`num' < 90
			matrix acr_t`num'`p'_b`b' = r(mean)
		}
	}
}

// organize bootstrap runs
clear
foreach num of numlist 1 2 {
	foreach p of numlist 0 1 {
		foreach b of numlist 1(1)$bootstraps {
			svmat  acr_t`num'`p'_b`b'
			rename acr_t`num'`p'_b`b'1 acr_t`num'`p'_b`b'
		}
		egen acr_t`num'`p'_p10 = rowpctile(acr_t`num'`p'_b*), p(10)
		egen acr_t`num'`p'_p90 = rowpctile(acr_t`num'`p'_b*), p(90)
		foreach var of varlist acr_t`num'`p'_b* {
			replace `var' = . if `var' > acr_t`num'`p'_p90 | `var' < acr_t`num'`p'_p10
		}
		egen acr_t`num'`p'_sd = rowsd(acr_t`num'`p'_b*)
		summ acr_t`num'`p'_sd
		matrix acr_t`num'`p'_sd = r(mean)
		drop acr_t`num'`p'_b* acr_t`num'`p'_p* acr_t`num'`p'_sd
	}
}

// main estimation
use  fine_event_percentiles.dta, clear
# delimit
reghdfe  fine        if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
	     absorb(i.simpleID i.ageyeargroups2) resid(fine_resid1) vce(cluster segroup);
# delimit cr
replace fine_resid1 =. if e(sample) == 0

# delimit
reghdfe  finealt_exp if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
	     absorb(i.simpleID i.ageyeargroups2) resid(fine_resid2) vce(cluster segroup);
# delimit cr
replace fine_resid2 =. if e(sample) == 0

foreach num of numlist 1 2 {
	# delimit
	reghdfe  children if year >= 1979 & year <= 2000 & age >= 15 & age <= 45, 
			 absorb(i.simpleID i.ageyeargroups`num') resid(children_resid`num') vce(cluster segroup);
	# delimit cr
	replace children_resid`num' =. if e(sample) == 0
	summ    children_resid`num' 
	replace children_resid`num' = (children_resid`num' - r(mean)) / r(sd)
}

// percentiles of interest
local num = 0 
foreach var of varlist fine_resid1 {
	local num = `num' + 1
	foreach p of numlist 60(5)95 {
		summ fine_resid`num', d
		bysort year: egen maxfine_t`num' = pctile(fine_resid`num'), p(`p')
		
		
		gen     maxcountaux_t`num' = 0 if fine_resid`num' !=.               & maxfine_t`num' !=. 
		replace maxcountaux_t`num' = 1 if fine_resid`num'  > maxfine_t`num' & fine_resid`num'     !=.               
		
		xtset simpleID age
		bysort simpleID : gen maxcount_t`num' = sum(maxcountaux_t`num') if maxcountaux_t`num' !=.
		

		gen     class_t`num' = 0 if fine_resid`num' !=.        & children !=.      & maxcount_t`num' !=.
		replace class_t`num' = 1 if maxcount_t`num' >= 2  & fine_resid`num' !=.    & children !=.        & maxcount_t`num' !=.
		
		// define event
		gen dclass_t`num' = class_t`num' - l.class_t`num'
		gen yeareventaux_t`num' = year if dclass_t`num' == 1
		bysort simpleID : egen yearevent_t`num' = min(yeareventaux_t`num') if class_t`num' !=.
		gen eventtime_t`num'_p`p' = year - yearevent_t`num'
		drop maxfine_t`num' maxcountaux_t`num' maxcount_t`num' class_t`num' dclass_t`num' yeareventaux_t`num' yearevent_t`num'
	}
}

foreach var of varlist fine_resid2 {
	local num = `num' + 1
	foreach p of numlist 60(5)95 {
		summ fine_resid`num', d
		bysort year: egen maxfine_t`num' = pctile(fine_resid`num'), p(`p')
		
		
		gen     maxcountaux_t`num' = 0 if fine_resid`num' !=.               & maxfine_t`num' !=. 
		replace maxcountaux_t`num' = 1 if fine_resid`num'  > maxfine_t`num' & fine_resid`num'     !=.               
		
		xtset simpleID age
		bysort simpleID : gen maxcount_t`num' = sum(maxcountaux_t`num') if maxcountaux_t`num' !=.
		

		gen     class_t`num' = 0 if fine_resid`num' !=.        & children !=.      & maxcount_t`num' !=.
		replace class_t`num' = 1 if maxcount_t`num' >= 2  & fine_resid`num' !=.    & children !=.        & maxcount_t`num' !=.
		
		// define event
		gen dclass_t`num' = class_t`num' - l.class_t`num'
		gen yeareventaux_t`num' = year if dclass_t`num' == 1
		bysort simpleID : egen yearevent_t`num' = min(yeareventaux_t`num') if class_t`num' !=.
		gen eventtime_t`num'_p`p' = year - yearevent_t`num'
		drop maxfine_t`num' maxcountaux_t`num' maxcount_t`num' class_t`num' dclass_t`num' yeareventaux_t`num' yearevent_t`num'
	}
}

// events
foreach num of numlist 1 2 {
	foreach p of numlist 60(5)95 {
		local numel = 0
		foreach numy of numlist -6(1)4 {
			local numel = `numel' + 1
			gen eventtime_t`num'_`numel'_p`p' = eventtime_t`num'_p`p' == `numy'
		}
		reg children_resid`num' eventtime_t`num'_1_p`p'-eventtime_t`num'_11_p`p' if eventtime_t`num'_p`p' >= -6 & eventtime_t`num'_p`p' <= 4, nocons
		matrix acr3_t`num'_p`p' = e(b)
		matrix acr3_t`num'_p`p' = acr3_t`num'_p`p'[1,1..11]'
	}
}

matrix acrall = J(11,1,.)
foreach p of numlist 60(5)95 {
	matrix acrall_p`p' = [acr3_t1_p`p',acr3_t2_p`p']
	matrix colnames acrall_p`p' = acr3_t1_p`p' acr3_t2_p`p'
	matrix acrall          = [acrall,acrall_p`p']
}
matrix acrall = acrall[1...,2...]

clear
svmat   acrall, names(col)
gen     eventtime = _n - 6

foreach var of varlist acr* {
	summ    `var' if eventtime == -1
	replace `var' = `var' - r(mean)
}

// average before and after 
drop if eventtime == -1
replace eventtime =  1 if eventtime >= 0
replace eventtime =  0 if eventtime < 0

collapse acr*, by(eventtime)
aorder
order eventtime 
mkmat acr3_t1*, matrix(acr_t1)
mkmat acr3_t2*, matrix(acr_t2)

clear
foreach num of numlist 1 2 {
	matrix acr_t`num' = acr_t`num''
	svmat  acr_t`num'
	rename acr_t`num'1 acr_t`num'0
	rename acr_t`num'2 acr_t`num'1
} 
gen n1 = _n*5 + 55
gen n2 = _n*5 + 60

foreach num of numlist 1 2 {
	foreach p of numlist 0 1 { 
		summ   acr_t`num'`p'  if n`num' > 60 & n`num' < 90
		matrix acr_t`num'`p' = r(mean)
	}
}

foreach num of numlist 1 2 { 
	foreach p of numlist 0 1 { 
		local acr_t`num'`p'    = string(acr_t`num'`p'[1,1],"%15.3f")
		local acr_t`num'`p'se  = string(acr_t`num'`p'_sd[1,1],"%15.3f")
	}
}


// plots
cd $output
# delimit
global box1  text(.03 80
	 "Before-Event Average:" 
	 "`acr_t10' (s.e. `acr_t10se')"
	 " "
	 "After-Event Average:" 
	 "`acr_t11' (s.e. `acr_t11se')"
         , size(small) box just(c) margin(l+1 b+1 t+1 r+1) fcolor(none)); 
# delimit cr

// documentation 
#delimit
twoway  
		(scatter acr_t10   n1 if n1 > 60 & n1 < 90, msymbol(circle) color(gs9)  msize(medlarge)            xline(-1 , lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(lowess  acr_t10   n1 if n1 > 60 & n1 < 90, lcolor(gs9) lwidth(medthick) bwidth(.8)                yline(.05, lpattern(solid) lcolor(gs14)))
		
		(scatter acr_t11   n1 if n1 > 60 & n1 < 90, msymbol(square) color(gs3)  msize(medlarge)            yline(0  , lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(lowess  acr_t11   n1 if n1 > 60 & n1 < 90, lcolor(gs3) lwidth(medthick) bwidth(.8)),
		
		legend(label(1 "Before Event") label(3 "After Event")  rows(1) order(1 3))

		  xlabel(, grid glcolor(gs14)) 
		  ylabel(.05[.05]-.15, angle(h) glcolor(gs14)) 
		  ytitle("Residual Average Flow of Children")
		  xtitle("Percentile of the Residual Price First Difference Defining Event")
		  graphregion(color(white)) plotregion(color(white)) $box1;
#delimit cr
graph export childrenfine_event_docptiles.eps, replace

# delimit
global box2  text(-.03 80
	 "Before-Event Average:" 
	 "`acr_t20' (s.e. `acr_t20se')"
	 " "
	 "After-Event  Average:" 
	 "`acr_t21' (s.e. `acr_t21se')"
         , size(small) box just(c) margin(l+1 b+1 t+1 r+1) fcolor(none)); 
# delimit cr

// surveys
#delimit
twoway  
		(scatter acr_t20   n2 if n2 < 90, msymbol(circle) color(gs9)  msize(medlarge)            xline(-1 , lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(lowess  acr_t20   n2 if n2 < 90, lcolor(gs9) lwidth(medthick) bwidth(.8)                yline(-.15, lpattern(solid) lcolor(gs14)))
		
		(scatter acr_t21   n2 if n2 < 90, msymbol(square) color(gs3)  msize(medlarge)            yline(0  , lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(lowess  acr_t21   n2 if n2 < 90, lcolor(gs3) lwidth(medthick) bwidth(.8)),
		
		legend(label(1 "Before Event") label(3 "After Event")  rows(1) order(1 3))

		  xlabel(, grid glcolor(gs14)) 
		  ylabel(.05[.05]-.15, angle(h) glcolor(gs14)) 
		  ytitle("Residual Average Flow of Children")
		  xtitle("Percentile of the Residual Price First Difference Defining Event")
		  graphregion(color(white)) plotregion(color(white))
		  $box2;
#delimit cr
graph export childrenfine_eventsurvptiles.eps, replace

// clean bootstrapped data file and save result sheet
erase fine_event_percentiles.dta
