version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1200

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

// community data
cd $dataraw
cd 2011
use community, clear
duplicates tag communityID, gen(reps)
keep if reps == 0 
tempfile community
save   "`community'", replace

cd $dataready
use charls_females.dta, clear

// generate delta children outcomes
gen     lchildren = l.children
drop if lchildren ==.
gen dchildren = children - l.children

// merge community-level data
merge m:1 communityID using "`community'", keepusing(jh*)
keep if _merge != 2

// data groups
egen ageyeargroups1 = group(age year province_code)
egen ageyeargroups2 = group(age year communityID)
egen segroup        = group(province_code birthyear)

// construct fine/permit variables
gen    allowedaddchild2000 = allowedaddchild if year == 1999
bysort simpleID : egen allowedaddchild2005 = mean(allowedaddchild2000)
replace allowedaddchild = allowedaddchild2005 if year >= 2000 & allowedaddchild2005 !=.
replace fine = 0 if allowedaddchild == 0

xtset simpleID age
# delimit
reghdfe dchildren  l.fine
		  if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
		  absorb(i.simpleID i.ageyeargroups1) cluster(segroup);
# delimit cr
keep if e(sample) == 1

// policy start
// measure (1) - community based 
bysort       simpleID : egen firstobserved = min(year)
bysort    communityID : egen policystart_1 = min(jh019)
replace policystart_1 = firstobserved if firstobserved > policystart_1 

// measure (2) - my documentation based 
sort simpleID age
gen     deltafine       = abs(fine - l.fine)
gen     policystart_2b   = year if deltafine > 0 & deltafine !=.  
replace policystart_2b   = year if fine      > 0 & fine !=. 
bysort       simpleID : egen policystart_2 = min(policystart_2b)

gen     finealt = 0         if jh026 == 2
replace finealt = 0         if jh026 == 1 & year <  jh026_1 
replace finealt = jh027     if jh026 == 1 & year >= jh026_1 & year !=.

replace finealt = jh029b_1_ if jh028 == 1 & year >= jh029a_1_ & year !=.
replace finealt = jh029b_2_ if jh028 == 1 & year >= jh029a_2_ & year !=.
replace finealt = jh029b_3_ if jh028 == 1 & year >= jh029a_3_ & year !=.

// with exemptions set by local leaders
gen     finealt_exp = finealt
replace finealt_exp = 0 if  jh020 == 2               &  firstchildgirl == 1 & selforspousehan == 1
replace finealt_exp = 0 if (jh020 == 3 | jh020 == 4) & selforspousehan == 1

// return to original fine in change in year of change and after  
replace finealt_exp = finealt if jh021 == 1 & year >= jh023 & year !=.

// put in exemptions
replace finealt_exp = 0 if  jh021 == 1 &  jh022 == 2               &  firstchildgirl == 1 & selforspousehan == 1 & year >= jh023 & year !=.
replace finealt_exp = 0 if  jh021 == 1 & (jh022 == 3 | jh022 == 4) & selforspousehan == 1 & year >= jh023 & year !=.

// live off from only one observation for minorities
replace finealt_exp = 0 if  jh025 == 2               &  firstchildgirl == 1 & selforspousehan == 0
replace finealt_exp = 0 if (jh025 == 3 | jh025 == 4) & selforspousehan == 0

summ    finealt_exp, d
replace finealt_exp =.  if finealt_exp > r(p95)
replace finealt_exp = 0 if allowedaddchild == 0

replace fine =.        if finealt_exp ==. | children ==.
replace finealt_exp =. if fine ==.        | children ==.

foreach var of varlist fine finealt_exp {
	summ    `var' if year == 1979
	replace `var' = `var'/r(mean)
	replace `var' = log(`var' + 1)
}
cd $output
drop _merge
save fine_event.dta, replace

// run bootstrap first to then proceed with plot
foreach b of numlist 1(1)$bootstraps {
	use fine_event.dta, clear
	drop segroup
	egen segroup       = group(province_code birthyear)
	keep simpleID segroup
	duplicates drop simpleID, force
	bsample, strata(segroup)
	drop segroup
	gen simpleIDalt = _n
	expand 166
	bysort simpleIDalt : egen age = seq()
	replace age = age - 63
	merge m:m simpleID age using fine_event.dta
	keep if _merge == 3
	drop simpleID _merge
	rename simpleIDalt simpleID
	xtset simpleID age
	
	# delimit
	reghdfe  fine        if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
			 absorb(i.simpleID i.ageyeargroups2) resid(fine_resid1) vce(cluster segroup);
	# delimit cr
	replace fine_resid1 =. if e(sample) == 0

	# delimit
	reghdfe  finealt_exp if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
			 absorb(i.simpleID i.ageyeargroups2) resid(fine_resid2) vce(cluster segroup);
	# delimit cr
	replace fine_resid2 =. if e(sample) == 0

	foreach num of numlist 1 2 {
		# delimit
		reghdfe  children if year >= 1979 & year <= 2000 & age >= 15 & age <= 45, 
				 absorb(i.simpleID i.ageyeargroups`num') resid(children_resid`num') vce(cluster segroup);
		# delimit cr
		replace children_resid`num' =. if e(sample) == 0
		summ    children_resid`num' 
		replace children_resid`num' = (children_resid`num' - r(mean)) / r(sd)
	}

	// percentiles of interest
	global fines fine_resid1 fine_resid2
	local num = 0 
	foreach var of varlist fine_resid1 {
		local num = `num' + 1
		summ fine_resid`num', d
		bysort year: egen maxfine_t`num' = pctile(fine_resid`num'), p(85)
		
		
		gen     maxcountaux_t`num' = 0 if fine_resid`num' !=.               & maxfine_t`num' !=. 
		replace maxcountaux_t`num' = 1 if fine_resid`num'  > maxfine_t`num' & fine_resid`num'     !=.               
		
		xtset simpleID age
		bysort simpleID : gen maxcount_t`num' = sum(maxcountaux_t`num') if maxcountaux_t`num' !=.
		

		gen     class_t`num' = 0 if fine_resid`num' !=.        & children !=.      & maxcount_t`num' !=.
		replace class_t`num' = 1 if maxcount_t`num' >= 2  & fine_resid`num' !=.    & children !=.        & maxcount_t`num' !=.
		
		// define event
		gen dclass_t`num' = class_t`num' - l.class_t`num'
		gen yeareventaux_t`num' = year if dclass_t`num' == 1
		bysort simpleID : egen yearevent_t`num' = min(yeareventaux_t`num') if class_t`num' !=.
		gen eventtime_t`num' = year - yearevent_t`num'
	}

	foreach var of varlist fine_resid2 {
		local num = `num' + 1
		summ fine_resid`num', d
		bysort year: egen maxfine_t`num' = pctile(fine_resid`num'), p(80)
		
		
		gen     maxcountaux_t`num' = 0 if fine_resid`num' !=.               & maxfine_t`num' !=. 
		replace maxcountaux_t`num' = 1 if fine_resid`num'  > maxfine_t`num' & fine_resid`num'     !=.               
		
		xtset simpleID age
		bysort simpleID : gen maxcount_t`num' = sum(maxcountaux_t`num') if maxcountaux_t`num' !=.
		

		gen     class_t`num' = 0 if fine_resid`num' !=.        & children !=.      & maxcount_t`num' !=.
		replace class_t`num' = 1 if maxcount_t`num' >= 2  & fine_resid`num' !=.    & children !=.        & maxcount_t`num' !=.
		
		// define event
		gen dclass_t`num' = class_t`num' - l.class_t`num'
		gen yeareventaux_t`num' = year if dclass_t`num' == 1
		bysort simpleID : egen yearevent_t`num' = min(yeareventaux_t`num') if class_t`num' !=.
		gen eventtime_t`num' = year - yearevent_t`num'
	}

	foreach num of numlist 1 2 {
			local numel = 0
			foreach numy of numlist -6(1)4 {
				local numel = `numel' + 1
				gen eventtime_t`num'_`numel' = eventtime_t`num' == `numy'
			}
		reg children_resid`num' eventtime_t`num'_1-eventtime_t`num'_11 if eventtime_t`num' >= -6 & eventtime_t`num' <= 4, nocons
		matrix acr3_t`num' = e(b)
		matrix acr3_t`num' = acr3_t`num'[1,1..11]'
	}
	matrix acrall_`b'          = [acr3_t1,acr3_t2]
	matrix colnames acrall_`b' = acr3_t1_`b' acr3_t2_`b'
	clear
	svmat   acrall_`b', names(col)
	gen     eventtime = _n - 6
	
	foreach var of varlist acr3_t1 acr3_t2 {
	summ    `var' if eventtime == -1
	replace `var' = `var' - r(mean)
	}
	drop if eventtime == -1
	gen     indevent = 0 if eventtime <  0
	replace indevent = 1 if eventtime >= 0
	collapse acr3_t1 acr3_t2, by(indev)
	mkmat acr3_t1 acr3_t2, matrix(acrall_`b')
	matrix colnames acrall_`b' = acr3_t1_b`b' acr3_t2_b`b'
	
}

// collect standard error
clear
set obs 2
gen event = _n -1
foreach b of numlist 1(1)$bootstraps {
	svmat acrall_`b', names(col)
}

foreach var in acr3_t1 acr3_t2 {
	egen `var'_p90 = rowpctile(`var'_b*), p(90)
	egen `var'_p10 = rowpctile(`var'_b*), p(10)
	foreach vary of varlist `var'_b* {
		replace `vary' =. if `vary' < `var'_p10 | `vary' > `var'_p90  
	}
	egen   `var'_se = rowsd(`var'_b*)
	
	summ   `var'_se  if event == 0
	matrix `var'_seb = r(mean) 
	summ   `var'_se    if event == 1
	matrix `var'_sea = r(mean) 
}

// main estimation
use fine_event.dta, clear
# delimit
reghdfe  fine        if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
	     absorb(i.simpleID i.ageyeargroups2) resid(fine_resid1) vce(cluster segroup);
# delimit cr
replace fine_resid1 =. if e(sample) == 0

# delimit
reghdfe  finealt_exp if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
	     absorb(i.simpleID i.ageyeargroups2) resid(fine_resid2) vce(cluster segroup);
# delimit cr
replace fine_resid2 =. if e(sample) == 0

foreach num of numlist 1 2 {
	# delimit
	reghdfe  children if year >= 1979 & year <= 2000 & age >= 15 & age <= 45, 
			 absorb(i.simpleID i.ageyeargroups`num') resid(children_resid`num') vce(cluster segroup);
	# delimit cr
	replace children_resid`num' =. if e(sample) == 0
	summ    children_resid`num' 
	replace children_resid`num' = (children_resid`num' - r(mean)) / r(sd)
}

// percentiles of interest
global fines fine_resid1 fine_resid2
local num = 0 
foreach var of varlist fine_resid1 {
	local num = `num' + 1
	summ fine_resid`num', d
	bysort year: egen maxfine_t`num' = pctile(fine_resid`num'), p(85)
	
	
	gen     maxcountaux_t`num' = 0 if fine_resid`num' !=.               & maxfine_t`num' !=. 
	replace maxcountaux_t`num' = 1 if fine_resid`num'  > maxfine_t`num' & fine_resid`num'     !=.               
	
	xtset simpleID age
	bysort simpleID : gen maxcount_t`num' = sum(maxcountaux_t`num') if maxcountaux_t`num' !=.
	

	gen     class_t`num' = 0 if fine_resid`num' !=.        & children !=.      & maxcount_t`num' !=.
	replace class_t`num' = 1 if maxcount_t`num' >= 2  & fine_resid`num' !=.    & children !=.        & maxcount_t`num' !=.
	
	// define event
	gen dclass_t`num' = class_t`num' - l.class_t`num'
	gen yeareventaux_t`num' = year if dclass_t`num' == 1
	bysort simpleID : egen yearevent_t`num' = min(yeareventaux_t`num') if class_t`num' !=.
	gen eventtime_t`num' = year - yearevent_t`num'
}

foreach var of varlist fine_resid2 {
	local num = `num' + 1
	summ fine_resid`num', d
	bysort year: egen maxfine_t`num' = pctile(fine_resid`num'), p(80)
	
	
	gen     maxcountaux_t`num' = 0 if fine_resid`num' !=.               & maxfine_t`num' !=. 
	replace maxcountaux_t`num' = 1 if fine_resid`num'  > maxfine_t`num' & fine_resid`num'     !=.               
	
	xtset simpleID age
	bysort simpleID : gen maxcount_t`num' = sum(maxcountaux_t`num') if maxcountaux_t`num' !=.
	

	gen     class_t`num' = 0 if fine_resid`num' !=.        & children !=.      & maxcount_t`num' !=.
	replace class_t`num' = 1 if maxcount_t`num' >= 2  & fine_resid`num' !=.    & children !=.        & maxcount_t`num' !=.
	
	// define event
	gen dclass_t`num' = class_t`num' - l.class_t`num'
	gen yeareventaux_t`num' = year if dclass_t`num' == 1
	bysort simpleID : egen yearevent_t`num' = min(yeareventaux_t`num') if class_t`num' !=.
	gen eventtime_t`num' = year - yearevent_t`num'
}

// events
foreach num of numlist 1 2 {
		local numel = 0
		foreach numy of numlist -6(1)4 {
			local numel = `numel' + 1
			gen eventtime_t`num'_`numel' = eventtime_t`num' == `numy'
		}
	reg children_resid`num' eventtime_t`num'_1-eventtime_t`num'_11 if eventtime_t`num' >= -6 & eventtime_t`num' <= 4, nocons
	matrix acr3_t`num' = e(b)
	matrix acr3_t`num' = acr3_t`num'[1,1..11]'
}
matrix acrall          = [acr3_t1,acr3_t2]
matrix colnames acrall = acr3_t1 acr3_t2

clear
svmat   acrall, names(col)
gen     eventtime = _n - 6

foreach var of varlist acr3_t1 acr3_t2 {
	summ    `var' if eventtime == -1
	replace `var' = `var' - r(mean)
}

// save se's for output
foreach num of numlist 1 2 {
	// save for output
	svmat  acr3_t`num'_seb
	rename acr3_t`num'_seb1 acr3_t`num'_seb

	svmat  acr3_t`num'_sea
	rename acr3_t`num'_sea1 acr3_t`num'_sea
}

// save output for plot
cd    $output
cd    resultsheets
save  childrenfine_event.dta, replace

/// plot plot plot
cd    $output
cd    resultsheets
use childrenfine_event.dta, clear
// make plot
// labels for individual regression
foreach num of numlist 1 2 {
	summ  acr3_t`num' if eventtime <   -1
	local acr3_t`num'b = r(mean)
	local acr3_t`num'b = string(`acr3_t`num'b',"%15.3f")
	
	summ   acr3_t`num'_seb 
	matrix acr3_t`num'_seb = r(mean)
	local acr3_t`num'_seb  = string(acr3_t`num'_seb[1,1],"%15.3f")
	
	summ  acr3_t`num' if eventtime >=  0
	local acr3_t`num'a = r(mean)
	local acr3_t`num'a = string(`acr3_t`num'a',"%15.3f")
	
	summ   acr3_t`num'_sea 
	matrix acr3_t`num'_sea = r(mean)
	local acr3_t`num'_sea  = string(acr3_t`num'_sea[1,1],"%15.3f")
}

# delimit
global box1  text(-.12 -3
	 "Event Time < -1: Average" 
	 " "
	 "Documenation: `acr3_t1b' (s.e `acr3_t1_seb')"
	 "Surveys: `acr3_t2b' (s.e `acr3_t2_seb')"
         , size(vsmall) box just(c) margin(l+1 b+1 t+1 r+1) fcolor(none)); 
# delimit cr

# delimit
global box2  text(.12 2.5
	 "Event Time {&ge} 0: Average" 
	 " "
	 "Documenation: `acr3_t1a' (s.e `acr3_t1_sea')"
	 "Surveys: `acr3_t2a' (s.e `acr3_t2_sea')"
         , size(vsmall) place(c) box just(c) margin(l+1 b+1 t+1 r+1) fcolor(none)); 
# delimit cr

cd $output
#delimit
twoway  
		(scatter acr3_t1   eventtime, msize(medlarge) msymbol(circle) mcolor(gs0)               xline(-1, lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(line    acr3_t1   eventtime if eventtime <  0, lcolor(gs0) lwidth(medium)           yline(.16 , lpattern(solid) lcolor(gs14)))
		(line    acr3_t1   eventtime if eventtime >= 0, lcolor(gs0) lwidth(medium))
		
		(scatter acr3_t2   eventtime, msize(medlarge) msymbol(square) mfcolor(none) mlcolor(gs0) yline(0  , lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(line    acr3_t2   eventtime if eventtime <  0, lcolor(gs0) lwidth(medium) lpattern(dash))
		(line    acr3_t2   eventtime if eventtime >= 0, lcolor(gs0) lwidth(medium) lpattern(dash)),
		
		legend(label(1 "Documentation") label(4 "Surveys")  rows(1) order(1 4))

		  xlabel(-5[1]5, grid glcolor(gs14)) 
		  ylabel(.16[.08]-.16, angle(h) glcolor(gs14)) 
		  ytitle("Residual Number of Children")
		  xtitle("Event Time in Years")
		  graphregion(color(white)) plotregion(color(white))
		  $box1 $box2;
#delimit cr
graph export childrenfine_event.eps, replace

// clean bootstrapped data file and save result sheet
erase fine_event.dta
