version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1200

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

// community data
cd $dataraw
cd 2011
use community, clear
duplicates tag communityID, gen(reps)
keep if reps == 0 
tempfile community
save   "`community'", replace

cd $dataready
use charls_females.dta, clear

replace     m_children = - m_children
egen     falt_children = rowtotal(children m_children), missing

replace     f_children = - f_children
egen     malt_children = rowtotal(children f_children), missing

drop   f_children    m_children
rename malt_children m_children
rename falt_children f_children

// generate delta children outcomes
foreach var of varlist children m_children f_children abortions inducedabortions miscarriages {
gen     l`var'  = l.`var'
gen      d`var' = `var' - l.`var'
}
drop if lchildren  ==.

// fraction of female / male
foreach s in m f {
	gen  `s'_ratio = `s'_children / children
	gen d`s'_ratio = `s'_ratio - l.`s'_ratio
}

// merge community-level data
merge m:1 communityID using "`community'", keepusing(jh*)
keep if _merge != 2

// data groups
egen ageyeargroups = group(age year province_code)
egen segroup       = group(province_code birthyear)
egen ageyeargroups1 = group(age year province_code)
egen ageyeargroups2 = group(age year communityID)

// construct fine/permit variables
gen    allowedaddchild2000 = allowedaddchild if year == 1999
bysort simpleID : egen allowedaddchild2005 = mean(allowedaddchild2000)
replace allowedaddchild = allowedaddchild2005 if year >= 2000 & allowedaddchild2005 !=.
replace fine = 0 if allowedaddchild == 0

xtset simpleID age
# delimit
reghdfe dchildren  l.fine
		  if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
		  absorb(i.simpleID i.ageyeargroups) cluster(segroup);
# delimit cr
keep if e(sample) == 1

// policy start
// measure (1) - community based 
bysort       simpleID : egen firstobserved = min(year)
bysort    communityID : egen policystart_1 = min(jh019)
replace policystart_1 = firstobserved if firstobserved > policystart_1 

// measure (2) - my documentation based 
sort simpleID age
gen     deltafine       = abs(fine - l.fine)
gen     policystart_2b   = year if deltafine > 0 & deltafine !=.  
replace policystart_2b   = year if fine      > 0 & fine !=. 
bysort       simpleID : egen policystart_2 = min(policystart_2b)

gen     finealt = 0         if jh026 == 2
replace finealt = 0         if jh026 == 1 & year <  jh026_1 
replace finealt = jh027     if jh026 == 1 & year >= jh026_1 & year !=.

replace finealt = jh029b_1_ if jh028 == 1 & year >= jh029a_1_ & year !=.
replace finealt = jh029b_2_ if jh028 == 1 & year >= jh029a_2_ & year !=.
replace finealt = jh029b_3_ if jh028 == 1 & year >= jh029a_3_ & year !=.

// with exemptions set by local leaders
gen     finealt_exp = finealt
replace finealt_exp = 0 if  jh020 == 2               &  firstchildgirl == 1 & selforspousehan == 1
replace finealt_exp = 0 if (jh020 == 3 | jh020 == 4) & selforspousehan == 1

// return to original fine in change in year of change and after  
replace finealt_exp = finealt if jh021 == 1 & year >= jh023 & year !=.

// put in exemptions
replace finealt_exp = 0 if  jh021 == 1 &  jh022 == 2               &  firstchildgirl == 1 & selforspousehan == 1 & year >= jh023 & year !=.
replace finealt_exp = 0 if  jh021 == 1 & (jh022 == 3 | jh022 == 4) & selforspousehan == 1 & year >= jh023 & year !=.

// live off from only one observation for minorities
replace finealt_exp = 0 if  jh025 == 2               &  firstchildgirl == 1 & selforspousehan == 0
replace finealt_exp = 0 if (jh025 == 3 | jh025 == 4) & selforspousehan == 0

gen ffinealt_exp = finealt_exp

summ    finealt_exp, d
replace finealt_exp =.  if finealt_exp > r(p95)
replace finealt_exp  = 0 if allowedaddchild == 0
replace ffinealt_exp = 0 if allowedaddchild == 0

gen ffine = fine 

replace fine =.        if finealt_exp ==. | children ==.
replace finealt_exp =. if fine ==.        | children ==.

foreach var of varlist fine finealt_exp ffine ffinealt_exp {
	summ    `var' if year == 1979
	replace `var' = `var'/r(mean)
	replace `var' = log(`var' + 1)
}

gen lfine         = l.fine
gen lfinealt_exp  = l.finealt_exp 
gen lffine        = l.ffine
gen lffinealt_exp = l.ffinealt_exp 

# delimit
reghdfe  dchildren lfine lfinealt_exp if year >= 1979 & year <= 2000 & age >= 15 & age <= 45,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr

// code some exemptions for heteroegeneity table
gen     exe1 = exemption5    													   // ethnicity
egen    exe4 = rowtotal(exemption6 exemption7 exemption9 exemption15), missing     // job difficulty
replace exe4 = 1 if exe4 >= 1 & exe4 !=.
egen    exe5 = rowtotal(exemption10 exemption11 exemption13), missing              // male scarcity
replace exe5 = 1 if exe5 >= 1 & exe5 !=.
gen     aghukou = 1 if bc001 == 1
replace aghukou = 0 if bc001 == 2

// construct controls for specification table
// population
global population total_males total_females total_population2 birth_rate death_rate first_natid second_natid
// (one factor)
foreach var of varlist $population {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var'
	
}

// employment 
global employment employed employed_urban staffand_workers stateowned_workers urbancollective_workers
// (one factor) 
foreach var of varlist $employment {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var' 
}

// health
# delimit 
global health health_institutions hospitals healthinstitutions_beds hospital_beds 
              doctors healthbeds_per10000 doctors_per10000; 
# delimit cr
// (one factor) 

foreach var of varlist $health {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var' 
}

// education 
# delimit 
global education highereducinst primaryschools highereducinst_teachers 
       regularsecondary_teachers primaryschools_teachers;
# delimit cr
// (one factor)

foreach var of varlist $education {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var' 
}

// trade
global trade retailsales total_exportsimports total_exports investment_fixedassets
// (one factor)

foreach var of varlist $trade {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var' 
}

// transportation and communications
# delimit 
global transportation railways_length highways_length totalpassengers railways_passengers 
                      highway_passengers freighttraffic freighttraffic_railways freighttraffic_highways 
		     civilmotorvehicles postandtelecomm numberofletters;
# delimit cr
// (one factor) 

foreach var of varlist $transportation {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var' 
}

// industry
# delimit
global industry industrialenterprises indusenter_state indusenter_collecti 
		industry_outputvalue  industry_outputvalue_collective 
		industry_clothes industry_paper industry_cigarettes industry_electricity industry_steel 
		industry_steelproducts indsutry_cement industry_fertilizer;
# delimit cr
// (factor 1)

foreach var of varlist $industry {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var' 
}

// government banking 
global govbanking localrevenue taxes localexpenditure
// (factor 1) 

foreach var of varlist $govbanking {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var' 
}

// agriculture
# delimit 
global agriculture  graincrops_kghectare cotton_kghectare oilbearingcrops_kghectare 
       agricultural_output agricultural_output_far agricultural_output_forestr 
       agricultural_output_husbran agricultural_output_fishery agriculturalmachinery 
       sownarea graincrops graintons oilbearingcropstons fruittons largeanimalsheads aquaticproductstons; 
# delimit cr
// (factor 1) 

foreach var of varlist $agriculture {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var' 
}

// economy 
# delimit 
global economy GDP industry primary_industry secondary_industry construction tertiary 
	       transportation GDP_percapita;
# delimit cr
// (factor 1)

foreach var of varlist $economy {
	bysort simpleID : ipolate `var' year, gen(i`var') epolate
	drop `var'
	rename i`var' `var' 
}

// subsidies
global subsidies unempsubs minallowance farmsubs reforsubs pension65 pension80 nrps orps
// (factor 1) 

// economy organization
global economicorganization hcrs rentland_fm rentland_nfm commune
// (factor 1) 

// put all the factors together and rotate them
# delimit 
global factors population employment health education trade transportation industry
	       govbanking agriculture economy subsidies economicorganization;
# delimit cr 

foreach faclist in $factors {
	factor ${`faclist'}
	predict factor_`faclist'
}	

//  construct and account for controls
# delimit
global X0 factor_population  factor_agriculture factor_transportation factor_industry 
          factor_employment  factor_trade  
	  factor_govbanking  factor_economicorganization factor_subsidies
	  factor_education   factor_economy;
# delimit cr 


// keepers
# delimit 
keep dchildren fine finealt_exp year age simpleID province_code birthyear communityID 
	 urban_ children m_children f_children abortions inducedabortions
	 segroup ageyeargroups* city province_name lchildren labortions linducedabortions lf_children lm_children 
	 lfine lfinealt_exp works firstchildgirl
	 dabortions df_children dm_children dinducedabortions dmiscarriages lmiscarriages miscarriages
	 healthtypedoctor *_ratio birthyearchild1 ocpstartyear  penaltyunplannedyear
	 exe1 exe4 exe5 worksoe aghukou $X0
	 lffine lffinealt_exp yearlyincome
	 noschool elementary middleschool highschool college;
# delimit cr

cd $dataready
// data set for dynamics models
save data_interim_dyn.dta, replace
drop if e(sample) == 0
// data set for other models
save data_interim.dta, replace
