version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1000

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// baseline regression (in working sample)
# delimit
ivreghdfe  dchildren (lfine =  lfinealt_exp) l.children,
		 absorb(i.simpleID i.ageyeargroups) cluster(segroup);
# delimit cr
gen insample = e(sample)

// define variables
// lump-sum file
gen     lump = 0 if province_name != " "
replace lump = 1 if province_name == "Beijing"           & year > 1992
replace lump = 1 if province_name == "Hebei"             & year > 1989
replace lump = 1 if province_name == "Inner Mongolia"    & year > 1995
replace lump = 1 if province_name == "Liaoning"          & year > 1992
replace lump = 1 if province_name == "Shanghai"          & year > 1992
replace lump = 1 if province_name == "Jiangsu"           & year > 1990
replace lump = 1 if province_name == "Fujian"            & year > 1991
replace lump = 1 if province_name == "Jiangxi"           
replace lump = 1 if province_name == "Shandong"          
replace lump = 1 if province_name == "Guangdong"         & year > 1992
replace lump = 1 if province_name == "Guangxi"

// ultrasound
// merge ultrasound data
rename    province_code province 
merge m:1 province using data_alz_jpe_ultracapitalcollapse
drop if _merge == 2
drop _merge

gen     ultraind = 0 if ultra_capital !=. & year !=.
replace ultraind = 1 if year > ultra_cap & ultra_cap !=. & year !=.

gen han     = 0 if exe1 == 1
replace han = 1 if exe1 != 1 

gen soe     = 0 if worksoe == 2 
replace soe = 1 if worksoe == 1

gen jobdiff     = 0 if exe4 == 0  
replace jobdiff = 1 if exe4 == 1  

gen malescarce     = 0 if exe5 == 0  
replace malescarce = 1 if exe5 == 1  

// some flips for description
replace firstchildgirl = 1 - firstchildgirl
replace urban_nbs = 1 - urban_nbs

// set flows as indicators
foreach var of varlist dchildren dm_children { 
	replace `var' = 1 if `var' > 1 & `var' !=.
}
xtset simpleID age
gen ldchildren = l.dchildren

// list descriptors
global fertility    lchildren lm_children linducedabortions dchildren dm_children dinducedabortions firstchildgirl works
global demographic  age urban_nbs aghukou han soe jobdiff malescarce 
global policy lffine lffinealt_exp lump
global samples mayorind l2targetlesscensusfertility accumumyearsinoffice

// gen lffine, lffinealt > 0
foreach var of varlist lffine lffinealt_exp {
	gen     ind`var' = exp(`var')
	replace ind`var' = ind`var' - 1 
    // replace ind`var' = 1 if ind`var' > 0 & ind`var' !=.
}

// convert prices into 2020 dollars
foreach var of varlist lffine lffinealt_exp {
	replace `var' = exp(`var')*4.5*1.19*326.027
}

// time periods
global period1 year >= 1980 & year <= 2000
global period2 year >= 1980 & year <= 1984 
global period3 year >= 1985 & year <= 1989 
global period4 year >= 1990 & year <= 1994  
global period5 year >= 1995 & year <= 2000

// observations
foreach num of numlist 1(1)5 {
	xtdes if ${period`num'} & insample == 1
	matrix   N_s`num' = r(N)
	matrix   A_s`num' = r(mean)
	matrix  NA_s`num' = [N_s`num' \ A_s`num']
}
matrix all_NA =[NA_s1,NA_s2,NA_s3,NA_s4,NA_s5]

// fertility variables
foreach num of numlist 1(1)5 {
	matrix all_p`num' = J(1,1,.) 
	foreach var of varlist $fertility {
		reg     `var' if age >= 15 & age <= 45 & year >= 1980 & year <= 2000 & insample == 1 & ${period`num'}
		mdesc   `var' if ${period`num'}
		matrix m`var' = r(percent) / 100  
		matrix  `var' = [e(b)[1,1] \ m`var'] 
		matrix all_p`num' = [all_p`num' \ `var']
	}
	matrix all_p`num' = all_p`num'[2...,1...]
}

// only defined for those with children
foreach num of numlist 1(1)5 {
	matrix all_p`num'_alt = J(1,1,.) 
	foreach var of varlist m_ratio {
		reg     `var' if age >= 15 & age <= 45 & year >= 1980 & year <= 2000 & insample == 1 & ${period`num'} & lchildren > 0 & lchildren !=.
		mdesc   `var' if ${period`num'} & lchildren > 0 & lchildren !=.
		matrix m`var' = r(percent) / 100  
		matrix  `var' = [e(b)[1,1] \ m`var'] 
		matrix all_p`num'_alt = [all_p`num'_alt \ `var']
	}
	matrix all_p`num'_alt = all_p`num'_alt[2...,1...]
}

// put together with fertility matrix
local colsall  = rowsof(all_p1) - 2
local colsall1 = `colsall' + 1
foreach num of numlist 1(1)5 {
	matrix all_p`num'_t = [all_p`num'[1..`colsall',1...] \ all_p`num'_alt \ all_p`num'[`colsall1'...,1...]]
}
matrix all_fert = [all_p1_t,all_p2_t,all_p3_t,all_p4_t,all_p5_t]

// policy variables
foreach num of numlist 1(1)5 {
	matrix all_p`num' = J(1,1,.) 
	foreach var of varlist $policy {
		reg     `var' if age >= 15 & age <= 45 & year >= 1980 & year <= 2000 & insample == 1 & ${period`num'}
		mdesc   `var' if ${period`num'}
		matrix m`var' = r(percent) / 100  
		matrix  `var' = [e(b)[1,1] \ m`var'] 
		matrix all_p`num' = [all_p`num' \ `var']
	}
	matrix all_p`num' = all_p`num'[2...,1...]
}
matrix all_policy = [all_p1,all_p2,all_p3,all_p4,all_p5]

// only for reporting in paper
reg indlffine if age >= 15 & age <= 45 & year >= 1980 & year <= 2000 & insample == 1 & ${period1}

// demographic 
foreach num of numlist 1(1)5 {
	matrix all_p`num' = J(1,1,.) 
	foreach var of varlist $demographic {
		reg     `var' if age >= 15 & age <= 45 & year >= 1980 & year <= 2000 & insample == 1 & ${period`num'}
		mdesc   `var' if ${period`num'}
		matrix m`var' = r(percent) / 100  
		matrix  `var' = [e(b)[1,1] \ m`var'] 
		matrix all_p`num' = [all_p`num' \ `var']
	}
	matrix all_p`num' = all_p`num'[2...,1...]
}
matrix all_dem = [all_p1,all_p2,all_p3,all_p4,all_p5]


//////// corroboration sample
// cadre promotion data 
preserve
cd $dataready
insheet  using charls_prefectures_withcodes.csv, clear
tempfile prefecturecodes
save   "`prefecturecodes'", replace

// community data
cd $dataraw
cd 2011
use community, clear
duplicates tag communityID, gen(reps)
keep if reps == 0 
tempfile community
save   "`community'", replace

cd $dataready
use charls_females.dta, clear

// generate delta children outcomes
gen     lchildren = l.children
drop if lchildren ==.
gen dchildren = children - l.children

// merge community-level data
merge m:1 communityID using "`community'", keepusing(jh*)
keep if _merge != 2

// data groups
egen ageyeargroups = group(age year province_code)
egen segroup       = group(province_code birthyear)

// construct fine/permit variables
// construct fine/permit variables
gen    allowedaddchild2000 = allowedaddchild if year == 1999
bysort simpleID : egen allowedaddchild2005 = mean(allowedaddchild2000)
replace allowedaddchild = allowedaddchild2005 if year >= 2000 & allowedaddchild2005 !=.
replace fine = 0 if allowedaddchild == 0

xtset simpleID age
# delimit
reghdfe dchildren  l.fine
		  if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
		  absorb(i.simpleID i.ageyeargroups) cluster(segroup);
# delimit cr
keep if e(sample) == 1

// policy start
// measure (1) - community based 
bysort       simpleID : egen firstobserved = min(year)
bysort    communityID : egen policystart_1 = min(jh019)
replace policystart_1 = firstobserved if firstobserved > policystart_1 

// measure (2) - my documentation based 
sort simpleID age
gen     deltafine       = abs(fine - l.fine)
gen     policystart_2b   = year if deltafine > 0 & deltafine !=.  
replace policystart_2b   = year if fine      > 0 & fine !=. 
bysort       simpleID : egen policystart_2 = min(policystart_2b)

gen     finealt = 0         if jh026 == 2
replace finealt = 0         if jh026 == 1 & year <  jh026_1 
replace finealt = jh027     if jh026 == 1 & year >= jh026_1 & year !=.

replace finealt = jh029b_1_ if jh028 == 1 & year >= jh029a_1_ & year !=.
replace finealt = jh029b_2_ if jh028 == 1 & year >= jh029a_2_ & year !=.
replace finealt = jh029b_3_ if jh028 == 1 & year >= jh029a_3_ & year !=.

// with exemptions set by local leaders
gen     finealt_exp = finealt
replace finealt_exp = 0 if  jh020 == 2               &  firstchildgirl == 1 & selforspousehan == 1
replace finealt_exp = 0 if (jh020 == 3 | jh020 == 4) & selforspousehan == 1

// return to original fine in change in year of change and after  
replace finealt_exp = finealt if jh021 == 1 & year >= jh023 & year !=.

// put in exemptions
replace finealt_exp = 0 if  jh021 == 1 &  jh022 == 2               &  firstchildgirl == 1 & selforspousehan == 1 & year >= jh023 & year !=.
replace finealt_exp = 0 if  jh021 == 1 & (jh022 == 3 | jh022 == 4) & selforspousehan == 1 & year >= jh023 & year !=.

// live off from only one observation for minorities
replace finealt_exp = 0 if  jh025 == 2               &  firstchildgirl == 1 & selforspousehan == 0
replace finealt_exp = 0 if (jh025 == 3 | jh025 == 4) & selforspousehan == 0

summ    finealt_exp, d
replace finealt_exp =.  if finealt_exp > r(p95)
replace finealt_exp = 0 if allowedaddchild == 0

replace fine =.        if finealt_exp ==. | children ==.
replace finealt_exp =. if fine ==.        | children ==.

foreach var of varlist fine finealt_exp {
	summ    `var' if year == 1979
	replace `var' = `var'/r(mean)
	replace `var' = log(`var' + 1)
}

# delimit
reghdfe  dchildren l.fine l.finealt_exp if year >= 1979 & year <= 2000 & age >= 15 & age <= 45,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
drop if e(sample) == 0

# delimit
reghdfe  l.fine        if year >= 1979 & year <= 2000 & age >= 15 & age <= 45,
	     absorb(i.simpleID i.ageyeargroups) resid(fine_resid1) vce(cluster segroup);
# delimit cr
replace fine_resid1 =. if e(sample) == 0

# delimit
reghdfe  l.finealt_exp if year >= 1979 & year <= 2000 & age >= 15 & age <= 45,
	     absorb(i.simpleID i.ageyeargroups) resid(fine_resid2) vce(cluster segroup);
# delimit cr
replace fine_resid2 =. if e(sample) == 0

// merge in prefectures codes
drop _merge
rename city prefecture_name
merge  m:m  prefecture_name province_name using "`prefecturecodes'"
keep if _merge == 3
drop _merge
drop segroup
egen segroup = group(prefectureid_1990 year)

// run base specification with non-missing prefecture id and then with fes
xtset simpleID age
# delimit
reghdfe     dchildren l.fine l.finealt_exp if age >= 15 & age <= 45 & year >= 1979 & year <= 2000 & prefectureid_1990 !=.,
            absorb(i.ID_ns i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1

// keep year in which mayor data are available 
keep if year >= 1985 & year <= 2000

// run base specification with non-missing prefecture id and relevant years
# delimit
reghdfe     d.children l.fine l.finealt_exp if age >= 15 & age <= 45 & year >= 1979 & year <= 2000 & prefectureid_1990 !=.,
            absorb(i.ID_ns i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1

// mere in information on cadres
merge m:1 prefectureid_1990 year using china_cadrepromotions
keep if _merge == 3
drop _merge

// run base speification with cadre subsample
xtset simpleID age
# delimit
reghdfe     dchildren l.fine l.finealt_exp if age >= 15 & age <= 45 & year >= 1979 & year <= 2000 & prefectureid_1990 !=.,
            absorb(i.ID_ns i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1
xtset ID_ns age

# delimit
reghdfe l.fine l2.targetlesscensusfertility, 
			 vce(cluster segroup) absorb(i.ID_ns i.age##i.year i.province_code); 
# delimit cr
gen  mayorind = e(sample)

gen    l2targetlesscensusfertility = l2.targetlesscensusfertility
gen     accumumyearsinofficeind = 1 if accumumyearsinoffice <= 2.5
replace accumumyearsinofficeind = 0 if accumumyearsinoffice >  2.5 & accumumyearsinoffice !=.
replace accumumyearsinofficeind = 1 - accumumyearsinofficeind

keep simpleID age mayorind l2targetlesscensusfertility accumumyearsinofficeind
tempfile mayorind 
save   "`mayorind'", replace
restore 

merge 1:1 simpleID age using "`mayorind'"
drop if _merge == 2
drop _merge

// mayors
foreach num of numlist 1 4 5 {
	matrix all_p`num' = J(1,1,.) 
	foreach var of varlist mayorind {
		reg     `var' if age >= 15 & age <= 45 & year >= 1980 & year <= 2000 & insample == 1 & ${period`num'}
		mdesc   `var' if ${period`num'}
		matrix m`var' = r(percent) / 100  
		matrix  `var' = [e(b)[1,1] \ m`var'] 
		matrix all_p`num' = [all_p`num' \ `var']
	}
	matrix all_p`num' = all_p`num'[2...,1...]
}
matrix all_other2 = [all_p1,J(2,1,.),J(2,1,.),all_p4,all_p5]

// within mayors
foreach num of numlist 1 4 5 {
	matrix all_p`num' = J(1,1,.) 
	foreach var of varlist l2targetlesscensusfertility accumumyearsinofficeind {
		reg     `var' if age >= 15 & age <= 45 & year >= 1980 & year <= 2000 & insample == 1 & ${period`num'} & mayorind == 1
		mdesc   `var' if ${period`num'} & mayorind == 1
		matrix m`var' = r(percent) / 100  
		matrix  `var' = [e(b)[1,1] \ m`var'] 
		matrix all_p`num' = [all_p`num' \ `var']
	}
	matrix all_p`num' = all_p`num'[2...,1...]
}
matrix all_other3 = [all_p1,J(4,1,.),J(4,1,.),all_p4,all_p5]

matrix all_other = [all_other2 \ all_other3]

matrix all = [J(2,5,.) \ all_NA \ J(1,5,.) \  all_dem \ J(1,5,.) \ all_fert \ J(1,5,.) \ all_policy \ J(1,5,.) \ all_other]
clear
svmat all

gen n = _n
foreach var of varlist all* {
	format  `var' %15.3fc
	replace `var' = round(`var',.001) 
	gen    `var'and = "&" if n !=1
}

gen all0and = "&" if n != 1
gen     all1_0 = "\begin{tabular}{ L{5cm} C{2cm} C{2cm} C{2cm} C{2cm} C{2cm} } \toprule & \underline{All} & \underline{1980-1984} & \underline{1985-1989} & \underline{1990-1994} & \underline{1995-2000} \\ \midrule"                  if n == 1

replace all1_0  = "\multicolumn{6}{l}{\textbf{\textit{Panel a.} Sample Size.}} "                          if n == 2
replace all0and = " "       																			  if n == 2 | n == 5 | n == 20 | n ==39 | n == 46
replace all1and = "   "           						      							  				  if n == 2 | n == 5 | n == 20 | n ==39 | n == 46
replace all2and = "   "           						      							  				  if n == 2 | n == 5 | n == 20 | n ==39 | n == 46
replace all3and = "   "       															  				  if n == 2 | n == 5 | n == 20 | n ==39 | n == 46
replace all4and = "   "           						      							  				  if n == 2 | n == 5 | n == 20 | n ==39 | n == 46

replace all1_0  = "\multicolumn{6}{l}{\textbf{\textit{Panel b.} Demographics.}} "                    if n == 5
replace all1_0  = "\multicolumn{6}{l}{\textbf{\textit{Panel c.} Fertility.}} "                       if n == 20
replace all1_0  = "\multicolumn{6}{l}{\textbf{\textit{Panel d.} Policy.}} "                          if n == 39
replace all1_0  = "\multicolumn{6}{l}{\textbf{\textit{Panel e.} Sample of Mayors.}}"                 if n == 46

order all1_0 all0and all1 all1and all2 all2and all3 all3and all4 all4and all5 all5and n
replace all5and = "\\" 
replace all5and = " "                       			    if n == 1

replace all1_0 = "$ N $ (Individuals) "             		if n == 3
replace all1_0 = "Average $ A_i$ (Periods Observed)"        if n == 4

replace all1_0 = "Age"             		    if n == 6
replace all1_0 = "Rural"            	    if n == 8
replace all1_0 = "Agricultural Hukou"       if n == 10
replace all1_0 = "Han Ethnicity"    	    if n == 12
replace all1_0 = "State-Enterprise Worker"  if n == 14
replace all1_0 = "Job Difficulty"   		if n == 16
replace all1_0 = "Male Scarcity"    		if n == 18

replace all1_0 = "Stock of Children"   		  if n == 21
replace all1_0 = "Stock of Boys"       		  if n == 23
replace all1_0 = "Stock of Abortions"  		  if n == 25
replace all1_0 = "Flow of Children"    	 	  if n == 27
replace all1_0 = "Flow of Boys"               if n == 29
replace all1_0 = "Flow of Abortions"          if n == 31
replace all1_0 = "Sex Ratio, 1\textsuperscript{st} Birth"         if n == 33
replace all1_0 = "(Boy per 100 Girls)"         					  if n == 34
replace all1_0 = "Sex Ratio, After 1\textsuperscript{st} Birth"   if n == 35
replace all1_0 = "(Boy per 100 Girls)"         					  if n == 36
replace all1_0 = "In Labor Force"                          	      if n == 37

replace all1_0 = "Price (2020 USD),"          if n == 40
replace all1_0 = "Documentation"              if n == 41
replace all1_0 = "Price (2020 USD),"          if n == 42
replace all1_0 = "Surveys"  				  if n == 43
replace all1_0 = "Lump-Sum Price"             if n == 44
replace all1_0 = "Province"                   if n == 45

replace all1_0 = "Fraction in Sample of Mayors"           if n == 47
replace all1_0 = "\ \ \ Mayor Performance"    if n == 49
replace all1_0 = "\ \ \ Experienced Mayor"    if n == 51

foreach num of numlist 7(2)19 22(2)38 41(2)45 48(2)52 { 
	replace all0and = " & \tiny{[" if n == `num'
	replace all5and = "]} \\ \\" if n == `num'
	foreach numy of numlist 1(1)4 {
		replace all`numy'and = "]} & \tiny{[" if n == `num'
	}
}

replace all5and = " \\ \midrule"                     if n == 4
replace all5and = "]} \\ \midrule"                   if n == 19 | n == 38 | n == 45
replace all5and = "]} \\ \bottomrule \end{tabular}"  if n == 52
replace all5and = "]} \\ \hdashline \\"     	     if n == 48 
replace all5and = "]} \\ \\" 			     		 if n == 50

foreach num of numlist 48(2)52 { 
	foreach numy of numlist 1 2 {
		replace all`numy'and = "&" if n == `num'
	}
	replace all1and = "]} &"  if n == `num'
	replace all2and = "&"    if n == `num'
	replace all3and = " & \tiny{[" if n == `num'
}

// convert ratios into standard sex ratios
foreach num of numlist 1(1)5 {
	replace all`num' = all`num'*205 if n == 33 | n == 35
}

// put together in string
gen all = " "
foreach num of numlist 1(1)5 {
	gen      all`num'b = all`num' if n == 3 | n == 40 | n == 42
	tostring all`num' , replace force format(%15.3fc)
	replace  all`num' = ""        if n == 3 | n == 40 | n == 42
	tostring all`num'b, replace force format(%15.0fc)
	replace  all`num'  = "" if all`num' == "."
	replace  all`num'b = "" if all`num'b == "."
}

global orderin all1_0 all0and
foreach num of numlist 1(1)5 {
	global orderin $orderin all`num' all`num'b all`num'and 
}
global orderin $orderin all`num'
order $orderin n

foreach var of varlist all1_0-all5and {
	
	replace  all = all + `var'
	replace  all`num' = "" if all`num' == "."
}
keep all
cd $output
outsheet using descriptive.tex, noquote nonames replace
